getPropertiesToBeSearchedKeyWord function
Class that holds the search results for getting the keyword as specified on the Doc
Implementation
///for getting the keyword as specified on the Doc
String getPropertiesToBeSearchedKeyWord(
ICDPropertiesSearch icdPropertiesSearch) {
if (icdPropertiesSearch == ICDPropertiesSearch.synonym) {
return 'Synonym';
} else if (icdPropertiesSearch == ICDPropertiesSearch.narrowerTerm) {
return 'NarrowerTerm';
} else if (icdPropertiesSearch == ICDPropertiesSearch.fullySpecifiedName) {
return 'FullySpecifiedName';
} else if (icdPropertiesSearch == ICDPropertiesSearch.definition) {
return 'Definition';
} else if (icdPropertiesSearch == ICDPropertiesSearch.exclusion) {
return 'Exclusion';
} else {
return 'Title';
}
}